@@ -7,7 +7,7 @@ from email.mime.text import MIMEText
 from email.utils import formatdate, make_msgid
 from smtplib import SMTP
 
-from ..consts import CONFIG, HOSTNAME, PROGRAMS, SERVICES
+from ..consts import CONFIG, HOSTNAME, MEDIA, PROGRAMS, SERVICES
 from .. import cluster, media, program, streaming
 from . import app
 
@@ -357,7 +357,9 @@ def update(obj, name, service_id):
     """Mise à jour des informations de media ou programme"""
     if obj == 'media':
         if name == 'all':  # on met tout à jour
-            media.Media.update()
+            with click.progressbar(media.Media.all()) as tsfiles:
+                for tsfile in tsfiles:
+                    MEDIA.set(tsfile.filename, tsfile.duration)
         else:
             media.Media(name).__update__()
     else:
